@@ -16,6 +16,7 @@
 import gtk
 import gobject
 import os
+import glib
 import gettext
 from gettext import gettext as _
 gettext.textdomain('quickly-widgets')
@@ -61,7 +62,8 @@ class Prompt(gtk.Dialog):
     action_area = p.get_action_area()
 
     Extending 
-    #Typically you will add widgets to a prompt
+    #Typically you will add widgets to a prompt and override the
+    #get_value function to return the appropriate value entered by the user.
     #String prompt is implemented as follows:
     class StringPrompt(Prompt):
         def __init__(self, title = "Input String",
@@ -94,6 +96,7 @@ class Prompt(gtk.Dialog):
 
         self.content_box = gtk.VBox(False, 10)
         label = gtk.Label(text)
+        label.set_line_wrap(True)
         self.content_box.pack_start(label,False, False, 5)
         content_area.pack_start(self.content_box)
         self.content_box.show()
@@ -113,6 +116,7 @@ def string(title = _("Input String"), text = _("Input a String:"), default_value
     (gtk.RESPONSE_DELETE_EVENT)
 
     """
+
     sp = StringPrompt(title, text, default_value)
     response = sp.run()
     val = sp.get_value()
@@ -141,6 +145,7 @@ class StringPrompt(Prompt):
     A StringPrompt is a Prompt which is gtk.Dialog
 
     """
+
     def __init__(self, title = _("Input String"), text = _("Input a String:"), default_value = ""):
         """Create a StringPrompt
         arguments:
@@ -161,6 +166,7 @@ class StringPrompt(Prompt):
         """get_value - returns the value the user has entered into the gtk.Entry
 
         """
+
         return self._entry.get_text()
 
 def date(title = _("Choose Date"), text = _("Choose a Date:"), default_value = None):
@@ -578,6 +584,7 @@ class YesNoPrompt(gtk.Dialog):
         no - a string that is a verb representing the No action
 
         """
+
         gtk.Dialog.__init__(self, title, None, gtk.DIALOG_MODAL)
 
         if no == "":
@@ -606,6 +613,7 @@ class YesNoPrompt(gtk.Dialog):
         img.set_from_stock(gtk.STOCK_DIALOG_QUESTION,gtk.ICON_SIZE_DIALOG)
         self.content_box.pack_start(img)
         label = gtk.Label(text)
+        label.set_line_wrap(True)
         self.content_box.pack_start(label,False, False, 5)
         content_area.pack_start(self.content_box)
         self.content_box.show()
@@ -681,11 +689,11 @@ class Alert(gtk.Dialog):
 
     Configuring
     #Add widgets to the content_box member
-    dp = DecimalPrompt(title, text, default_number)
-    dp.content_box.pack_end(my_additional_widget)
+    alert = Alert(title, text, image)
+    alert.content_box.pack_end(my_additional_widget)
 
     #change the image by passing in a stock gtk image
-    dp.set_image(stock_image)
+    alert.set_image(stock_image)
 
     Extending
     An Alert is a gtk.Dialog.
@@ -701,6 +709,7 @@ class Alert(gtk.Dialog):
 
         self.content_box = gtk.HBox(False, 10)
         label = gtk.Label(text)
+        label.set_line_wrap(True)
         self._image = gtk.Image()
         self._image.set_from_stock(image,gtk.ICON_SIZE_DIALOG)
         self.content_box.pack_start(self._image, False, False, 5)
@@ -728,6 +737,7 @@ def save_image_file(title=_("Choose an Image"),path=None):
     dialogv(gtk.RESPONSE_DELETE_EVENT)
 
     """
+
     sid = SaveImageDialog(title,path)
     response = sid.run()
     value = sid.get_filename()
@@ -772,7 +782,7 @@ class ImageDialog(gtk.FileChooserDialog):
         self.set_default_response(gtk.RESPONSE_OK)
 
         if path == None:
-            path = os.path.join(os.environ["HOME"], "Pictures")        
+            path = glib.get_user_special_dir(glib.USER_DIRECTORY_PICTURES)        
         self.set_current_folder(path)
 
         self._filter = gtk.FileFilter()
@@ -866,10 +876,12 @@ def open_image_file(title=_("Choose an Image"),path=None):
     path - a string providing a path to a directory where the
     dialog should start. Defaults to Pictures directory.
 
-    returns a gtk.DialogResponse
+     returns a tuple of (gtk.DialogResponse, str)
     gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user clicked "Cancel" or the userdismissed the 
-    dialogv(gtk.RESPONSE_DELETE_EVENT)
+    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
+    (gtk.RESPONSE_DELETE_EVENT)
+    The str is the path to the image chosen by the user, if any.
+
 
     """
 
@@ -887,10 +899,12 @@ def choose_directory(title=_("Choose a Directory"),path=None):
     path - a string providing a path to a directory where the
     dialog should start.
 
-    returns a gtk.DialogResponse
+
+    returns a tuple of (gtk.DialogResponse, str)
     gtk.RESPONSE_OK means the user clicked the "OK" button, otherwise
-    the user clicked "Cancel" or the userdismissed the 
-    dialogv(gtk.RESPONSE_DELETE_EVENT)
+    the user cancelled (gtk.RESPONSE_CANCEL) or dismissed the dialog
+    (gtk.RESPONSE_DELETE_EVENT)
+    The str is the path to the directory chosen by the user, if any.
 
     """
 
